// Copyright 2018 Google LLC All Rights Reserved.
// You may study, modify, and use this example for any purpose.
// Note that this example is provided "as is", WITHOUT WARRANTY
// of any kind either expressed or implied.

let nonceLoader;
let managerPromise;

/**
 * Initializes the PAL loader.
 */
function init() {
  document.getElementById('generate-nonce')
      .addEventListener('click', generateNonce);
  nonceLoader = new goog.pal.NonceLoader();
}

/**
 * Generates a nonce with sample arguments and logs it to the console. Note that
 * the onImpression() and onClick() methods should be called on the NonceManager
 * when the ad is played or clicked on respectively.
 */
function generateNonce() {
  const request = new goog.pal.NonceRequest();
  request.adWillAutoPlay = true;
  request.adWillPlayMuted = true;
  request.continuousPlayback = false;
  request.descriptionUrl = 'https://example.com';
  request.iconsSupported = true;
  request.playerType = 'Sample Player Type';
  request.playerVersion = '1.0';
  request.ppid = 'Sample PPID';
  request.videoHeight = 480;
  request.videoWidth = 640;

  managerPromise = nonceLoader.loadNonceManager(request);
  managerPromise
      .then((manager) => {
        console.log('Nonce generated: ' + manager.getNonce());
      })
      .catch((error) => {
        console.log('Error generating nonce: ' + error);
      });
}

init();
